@@ -22,12 +22,146 @@
 # @author Jeff Green,   ParIT Worker Co-operative <jeff@parit.ca>
 
 # The following is for doxygen
+
+## @defgroup python_bindings Python Bindings Module
+#  Also have a look at the page @ref python_bindings_page.
+
+## @defgroup python_bindings_examples Python Bindings Examples Module
+#  @ingroup python_bindings
+#  The python-bindings come with quite a lot of example scripts.
+
+##  @page python_bindings_page Python bindings
+#   Also have a look at group @ref python_bindings.
+#
+#   In the source tree they are located at bindings/python.
+#
+#   To enable them in the compilation process you have to add  -DWITH_PYTHON=ON
+#   to the call of cmake.
+#
+#   As a starting point have a look at the \link python_bindings_examples example-scripts\endlink.
+#
+#   @section possibilities What can Python Bindings be used for ?
+#
+#   The python bindings supply the ability to access a wide range of the core functions of GnuCash. You
+#   can read and write Transactions, Commodities, Lots, access the business stuff... You gain the ability
+#   to manipulate your financial data with a flexible scripting language.
+#
+#   Not everything GnuCash can is possible to access though. The bindings focus on basic accounting functions.
+#   Have a look at the examples to get an impression.
+#
+#   Some functions are broken because they have not been wrapped properly. They may crash the program or return unaccessible values.
+#   Please file a bug report if you find one to help support the development process.
+#
+#   @section python_bindings_section Principles
+#   The python-bindings are generated using SWIG from parts of the source-files of GnuCash.
+#
+#   @note Python-scripts should not be executed while GnuCash runs. GnuCash is designed as
+#   a single user application with only one program accessing the data at one time. You can force your
+#   access but that may corrupt data. Maybe one day that may change but for the moment there is no active development on that.
+#
+#   @subsection swigworks What SWIG does
+#
+#   SWIG extracts information from the c-sources and provides access to the structures
+#   to python. It's work is controlled by interface files :
+#
+#   @li gnucash_core.i
+#   @li timespec.i
+#   @li glib.i
+#   @li @link base-typemaps.i src/base-typemaps.i @endlink This file is shared with Guile.
+#
+#   it outputs:
+#
+#   @li gnucash_core.c
+#   @li gnucash_core_c.py
+#
+#   If you have generated your own local doxygen documentation (by "make doc") after having compiled the python-bindings, doxygen
+#   will include SWIGs output-files.
+#   It's actually quite interesting to have a look at them through doxygen, because they contain all that you can
+#   access from python.
+#
+#   This c-style-api is the bottom layer. It is a quite raw extract and close to the original source. Some more details are described further down.
+#
+#   For some parts there is a second layer of a nice pythonic interface. It is declared
+#   in
+#   @li gnucash_core.py and
+#   @li gnucash_business.py.
+#   @li function_class.py contains helper functions for that.
+#
+#   @section howto How to use the Python bindings
+#   @subsection highlevel High level python wrapper classes
+#   If you
+#
+#   @code >> import gnucash @endcode
+#
+#   You can access the structures of the high level api. For Example you get a Session object by
+#
+#   @code >> session=gnucash.Session() @endcode
+#
+#   Here you will find easy to use things. But sometimes - and at the current level rather sooner than
+#   later - you may be forced to search for solutions at the :
+#
+#   @subsection c_style_api C-style-api
+#
+#   If you
+#
+#   @code >> import gnucash @endcode
+#
+#   The c-style-api can be accessed via gnucash.gnucash_core_c. You can have a look at all the possibilities
+#   at gnucash_core_c.py.
+#
+#   You will find a lot of pointers here which you can just ignore if input and output of the function have the
+#   same type.
+#
+#   For example you could start a session by gnucash.gnucash_core_c.qof_session_begin(). But if you just try
+#
+#   @code session=gnucash.gnucash_core_c.qof_session_begin() @endcode
+#
+#   you will get an error message and realize the lack of convenience for you have to add the correct function parameters.
+#
+#   Not all of the available structures will work. SWIG just takes everything from the sources that it is fed with and translates it. Not everything
+#   is a working translation, because not everything has been worked through. At this point you are getting closer to the developers who you can
+#   contact at the mailing-list gnucash-devel@gnucash.org. There may be a workaround. Maybe the problem can only be fixed by changing SWIGs input
+#   files to correctly translate the c-source. Feel free to post a question at the developers list. It may awaken the interest of someone who creates
+#   some more beautiful python-interfaces.
+#
+#   @section Thisorthat When to use which api ?
+#
+#   The start would surely be the high-level api for you can be quite sure to have something working and you will maybe find
+#   explanations in the example-scripts. If you search for something that is not yet implemented in that way you will have to
+#   take your way to the c-style-api.
+#
+#   @section pydoc (Further) documentation
+#
+#   @li The documentation you just read uses doxygen. It collects documentation in GnuCash's sources. Besides that there is
+#   @li the classic python-documentation using help() and docstrings. Have a look at both.
+#   @li There is a page in the GnuCash wiki at https://wiki.gnucash.org/wiki/Python
+#   @li You may also have a look into the archives of gnucash-devel@gnucash.org.
+#   @li On Bugzilla there is also some interesting talk regarding the development process.
+#   @li Then you can use the abilities of git to see the history of the code by @code git log @endcode done in the directory of the python-bindings.
+#
+#   @section pytodo To-Do
+#   @li Work out the relation of scheme/guile and python-bindings
+#   @li maybe join python_bindings_page and group
+#   @li work on the structure of the documentation to make it more clear
+#   @li try to make SWIG include the documentation of the c-source
+#   @li make function-links in SWIG-generated files work.
+#   @li some words to the tests
+#
+# @author Christoph Holtermann
+# @date December 2010
+
+
 ## @file
 #  @brief High level python wrapper classes for the core parts of GnuCash
 #  @author Mark Jenkins, ParIT Worker Co-operative <mark@parit.ca>
 #  @author Jeff Green,   ParIT Worker Co-operative <jeff@parit.ca>
 #  @ingroup python_bindings
 
+import operator
+
+from enum import IntEnum
+from urllib.parse import urlparse
+
 from gnucash import gnucash_core_c
 from gnucash import _sw_core_utils
 
@@ -44,8 +178,15 @@ from gnucash.gnucash_core_c import gncInvoiceLookup, gncInvoiceGetInvoiceFromTxn
     gnc_search_customer_on_id, gnc_search_bill_on_id , \
     gnc_search_vendor_on_id, gncInvoiceNextID, gncCustomerNextID, \
     gncVendorNextID, gncTaxTableGetTables, gnc_numeric_zero, \
-    gnc_numeric_create, double_to_gnc_numeric, string_to_gnc_numeric, \
-    gnc_numeric_to_string
+    gnc_numeric_create, double_to_gnc_numeric, gnc_numeric_from_string, \
+    gnc_numeric_to_string, gnc_numeric_check
+
+from gnucash.deprecation import (
+    deprecated_args_session,
+    deprecated_args_session_init,
+    deprecated_args_session_begin,
+    deprecated
+)
 
 try:
     import gettext
@@ -83,6 +224,57 @@ class GnuCashBackendException(Exception):
         Exception.__init__(self, msg)
         self.errors = errors
 
+
+class SessionOpenMode(IntEnum):
+    """Mode for opening sessions.
+
+    This replaces three booleans that were passed in order: ignore_lock, create,
+    and force. It's structured so that one can use it as a bit field with the
+    values in the same order, i.e. ignore_lock = 1 << 2, create_new = 1 << 1, and
+    force_new = 1.
+
+    enumeration members
+    -------------------
+
+    SESSION_NORMAL_OPEN = 0     (All False)
+    Open will fail if the URI doesn't exist or is locked.
+
+    SESSION_NEW_STORE = 2       (False, True, False (create))
+    Create a new store at the URI. It will fail if the store already exists and is found to contain data that would be overwritten.
+
+    SESSION_NEW_OVERWRITE = 3   (False, True, True (create | force))
+    Create a new store at the URI even if a store already exists there.
+
+    SESSION_READ_ONLY = 4,      (True, False, False (ignore_lock))
+    Open the session read-only, ignoring any existing lock and not creating one if the URI isn't locked.
+
+    SESSION_BREAK_LOCK = 5     (True, False, True (ignore_lock | force))
+    Open the session, taking over any existing lock.
+
+    source: lignucash/engine/qofsession.h
+    """
+
+    SESSION_NORMAL_OPEN = gnucash_core_c.SESSION_NORMAL_OPEN
+    """All False
+    Open will fail if the URI doesn't exist or is locked."""
+
+    SESSION_NEW_STORE = gnucash_core_c.SESSION_NEW_STORE
+    """False, True, False (create)
+    Create a new store at the URI. It will fail if the store already exists and is found to contain data that would be overwritten."""
+
+    SESSION_NEW_OVERWRITE = gnucash_core_c.SESSION_NEW_OVERWRITE
+    """False, True, True (create | force)
+    Create a new store at the URI even if a store already exists there."""
+
+    SESSION_READ_ONLY = gnucash_core_c.SESSION_READ_ONLY
+    """True, False, False (ignore_lock)
+    Open the session read-only, ignoring any existing lock and not creating one if the URI isn't locked."""
+
+    SESSION_BREAK_LOCK = gnucash_core_c.SESSION_BREAK_LOCK
+    """True, False, True (ignore_lock | force)
+    Open the session, taking over any existing lock."""
+
+
 class Session(GnuCashCoreClass):
     """A GnuCash book editing session
 
@@ -96,45 +288,76 @@ class Session(GnuCashCoreClass):
     Invoice..) is associated with a particular book where it is stored.
     """
 
-    def __init__(self, book_uri=None, ignore_lock=False, is_new=False,
-                 force_new=False, instance=None):
-        """A convenient constructor that allows you to specify a book URI,
+    @deprecated_args_session_init
+    def __init__(self, book_uri=None, mode=None, instance=None, book=None):
+        """!
+        A convenient constructor that allows you to specify a book URI,
         begin the session, and load the book.
 
         This can give you the power of calling
         qof_session_new, qof_session_begin, and qof_session_load all in one!
 
-        book_uri can be None to skip the calls to qof_session_begin and
-        qof_session_load, or it can be a string like "file:/test.xac"
+        qof_session_load is only called if url scheme is "xml" and
+        mode is SESSION_NEW_STORE or SESSION_NEW_OVERWRITE
 
-        qof_session_load is only called if is_new is set to False
+        @param book_uri must be a string in the form of a URI/URL. The access
+        method specified depends on the loaded backends. Paths may be relative
+        or absolute.  If the path is relative, that is if the argument is
+        "file://somefile.xml", then the current working directory is
+        assumed. Customized backends can choose to search other
+        application-specific directories or URI schemes as well.
+        It be None to skip the calls to qof_session_begin and
+        qof_session_load.
 
-        is_new is passed to qof_session_begin as the argument create,
-        and force_new as the argument force. Is_new will create a new
-        database or file; force will force creation even if it will
-        destroy an existing dataset.
-
-        ignore_lock is passed to qof_session_begin's argument of the
-        same name and is used to break an existing lock on a dataset.
-
-        instance argument can be passed if new Session is used as a
+        @param instance argument can be passed if new Session is used as a
         wrapper for an existing session instance
 
+        @param mode The SessionOpenMode.
+        @note SessionOpenMode replaces deprecated ignore_lock, is_new and force_new.
 
-        This function can raise a GnuCashBackendException. If it does,
+        @par SessionOpenMode
+        `SESSION_NORMAL_OPEN`: Find an existing file or database at the provided uri and
+        open it if it is unlocked. If it is locked post a QOF_BACKEND_LOCKED error.
+        @par
+        `SESSION_NEW_STORE`: Check for an existing file or database at the provided
+        uri and if none is found, create it. If the file or database exists post a
+        QOF_BACKED_STORE_EXISTS and return.
+        @par
+        `SESSION_NEW_OVERWRITE`: Create a new file or database at the provided uri,
+        deleting any existing file or database.
+        @par
+        `SESSION_READ_ONLY`: Find an existing file or database and open it without
+        disturbing the lock if it exists or setting one if not. This will also set a
+        flag on the book that will prevent many elements from being edited and will
+        prevent the backend from saving any edits.
+        @par
+        `SESSION_BREAK_LOCK`: Find an existing file or database, lock it, and open
+        it. If there is already a lock replace it with a new one for this session.
+
+        @par Errors
+        qof_session_begin() signals failure by queuing errors. After it completes use
+        qof_session_get_error() and test that the value is `ERROR_BACKEND_NONE` to
+        determine that the session began successfully.
+
+        @exception as begin() and load() are wrapped with raise_backend_errors_after_call()
+        this function can raise a GnuCashBackendException. If it does,
         you don't need to cleanup and call end() and destroy(), that is handled
         for you, and the exception is raised.
         """
-        GnuCashCoreClass.__init__(self, Book())
+        if instance is not None:
+            GnuCashCoreClass.__init__(self, instance=instance)
+        else:
+            if book is None:
+                book = Book()
+            GnuCashCoreClass.__init__(self, book)
+
         if book_uri is not None:
             try:
-                self.begin(book_uri, ignore_lock, is_new, force_new)
-                # Take care of backend inconsistency
-                # New xml file can't be loaded, new sql store
-                # has to be loaded before it can be altered
-                # Any existing store obviously has to be loaded
-                # More background: https://bugs.gnucash.org/show_bug.cgi?id=726891
-                if book_uri[:3] != "xml" or not is_new:
+                if mode is None:
+                    mode = SessionOpenMode.SESSION_NORMAL_OPEN
+                self.begin(book_uri, mode)
+                is_new = mode in (SessionOpenMode.SESSION_NEW_STORE, SessionOpenMode.SESSION_NEW_OVERWRITE)
+                if not is_new:
                     self.load()
             except GnuCashBackendException as backend_exception:
                 self.end()
@@ -177,12 +400,12 @@ class Session(GnuCashCoreClass):
 
     # STATIC METHODS
     @staticmethod
-    def raise_backend_errors_after_call(function):
+    def raise_backend_errors_after_call(function, *args, **kwargs):
         """A function decorator that results in a call to
         raise_backend_errors after execution.
         """
-        def new_function(self, *args):
-            return_value = function(self, *args)
+        def new_function(self, *args, **kwargs):
+            return_value = function(self, *args, **kwargs)
             self.raise_backend_errors(function.__name__)
             return return_value
         return new_function
@@ -328,16 +551,18 @@ class GncNumeric(GnuCashCoreClass):
         elif len(args) == 1:
             arg = args[0]
             if isinstance(arg, int):
-                return gnc_numeric_create(arg ,1)
+                return gnc_numeric_create(arg, 1)
             elif isinstance(arg, float):
                 return double_to_gnc_numeric(arg, GNC_DENOM_AUTO, GNC_HOW_DENOM_FIXED | GNC_HOW_RND_NEVER)
             elif isinstance(arg, str):
-                instance = gnc_numeric_zero()
-                if not string_to_gnc_numeric(arg, instance):
+                instance = gnc_numeric_from_string(arg)
+                if gnc_numeric_check(instance):
                     raise TypeError('Failed to convert to GncNumeric: ' + str(args))
                 return instance
+            elif isinstance(arg, GncNumeric):
+                return arg.instance
             else:
-                raise TypeError('Only single int/float/str allowed: ' + str(args))
+                raise TypeError('Only single int/float/str/GncNumeric allowed: ' + str(args))
         elif len(args) == 2:
             if isinstance(args[0], int) and isinstance(args[1], int):
                 return gnc_numeric_create(*args)
@@ -353,6 +578,133 @@ class GncNumeric(GnuCashCoreClass):
         else:
             raise TypeError('Required single int/float/str or two ints: ' + str(args))
 
+    # from https://docs.python.org/3/library/numbers.html#numbers.Integral
+    # and https://github.com/python/cpython/blob/3.7/Lib/fractions.py
+
+    def _operator_fallbacks(monomorphic_operator, fallback_operator):
+        """fallbacks are not needed except for method name,
+        keep for possible later use"""
+        def forward(a, b):
+            if isinstance(b, GncNumeric):
+                return monomorphic_operator(a, b)
+            if isinstance(b, (int, float)):
+                return monomorphic_operator(a, GncNumeric(b))
+            else:
+                return NotImplemented
+        forward.__name__ = '__' + fallback_operator.__name__ + '__'
+        forward.__doc__ = monomorphic_operator.__doc__
+
+        def reverse(b, a):
+            if isinstance(a, (GncNumeric, int, float)):
+                return forward(b, a)
+            else:
+                return NotImplemented
+        reverse.__name__ = '__r' + fallback_operator.__name__ + '__'
+        reverse.__doc__ = monomorphic_operator.__doc__
+
+        return forward, reverse
+
+    def _add(a, b):
+        return a.add(b, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND)
+
+    def _sub(a, b):
+        return a.sub(b, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND)
+
+    def _mul(a, b):
+        return a.mul(b, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND)
+
+    def _div(a, b):
+        return a.div(b, GNC_DENOM_AUTO, GNC_HOW_RND_ROUND)
+
+    def _floordiv(a, b):
+        return a.div(b, 1, GNC_HOW_RND_TRUNC)
+
+    __add__, __radd__ = _operator_fallbacks(_add, operator.add)
+    __iadd__ = __add__
+    __sub__, __rsub__ = _operator_fallbacks(_sub, operator.sub)
+    __isub__ = __sub__
+    __mul__, __rmul__ = _operator_fallbacks(_mul, operator.mul)
+    __imul__ = __mul__
+    __truediv__, __rtruediv__ = _operator_fallbacks(_div, operator.truediv)
+    __itruediv__ = __truediv__
+    __floordiv__, __rfloordiv__ = _operator_fallbacks(_floordiv, operator.floordiv)
+    __ifloordiv__ = __floordiv__
+
+    # Comparisons derived from https://github.com/python/cpython/blob/3.7/Lib/fractions.py
+    def _lt(a, b):
+        return a.compare(b) == -1
+
+    def _gt(a, b):
+        return a.compare(b) == 1
+
+    def _le(a, b):
+        return a.compare(b) in (0,-1)
+
+    def _ge(a, b):
+        return a.compare(b) in (0,1)
+
+    def _eq(a, b):
+        return a.compare(b) == 0
+
+    def _richcmp(self, other, op):
+        """Helper for comparison operators, for internal use only.
+        Implement comparison between a GncNumeric instance `self`,
+        and either another GncNumeric instance, an int or a float
+        `other`.  If `other` is not an instance of that kind, return
+        NotImplemented. `op` should be one of the six standard
+        comparison operators. The comparisons are based on
+        GncNumeric.compare().
+        """
+        import math
+        if isinstance(other, GncNumeric):
+            return op(other)
+        elif isinstance(other, (int, float)):
+            return op(GncNumeric(other))
+        else:
+            return NotImplemented
+
+    def __lt__(a, b):
+        """a < b"""
+        return a._richcmp(b, a._lt)
+
+    def __gt__(a, b):
+        """a > b"""
+        return a._richcmp(b, a._gt)
+
+    def __le__(a, b):
+        """a <= b"""
+        return a._richcmp(b, a._le)
+
+    def __ge__(a, b):
+        """a >= b"""
+        return a._richcmp(b, a._ge)
+
+    def __eq__(a, b):
+        """a == b"""
+        return a._richcmp(b, a._eq)
+
+    def __bool__(a):
+        """a != 0"""
+        return bool(a.num())
+
+    def __float__(self):
+        return self.to_double()
+
+    def __int__(self):
+        return int(self.to_double())
+
+    def __pos__(a):
+        """+a"""
+        return GncNumeric(a.num(), a.denom())
+
+    def __neg__(a):
+        """-a"""
+        return a.neg()
+
+    def __abs__(a):
+        """abs(a)"""
+        return a.abs()
+
     def to_fraction(self):
         from fractions import Fraction
         return Fraction(self.num(), self.denom())
@@ -405,11 +757,19 @@ class GncPriceDB(GnuCashCoreClass):
     See also https://code.gnucash.org/docs/head/gnc-pricedb_8h.html
     '''
 
+@deprecated("Use gnc_pricedb_latest_before_t64")
+def gnc_pricedb_lookup_latest_before_t64(self, commodity, currency, date):
+    return self.lookup_nearest_before_t64(commodity, currency, date)
+
+GncPriceDB.add_method('gnc_pricedb_lookup_latest_before_t64', 'lookup_latest_before_t64')
+
+GncPriceDB.lookup_latest_before_t64 = method_function_returns_instance(GncPriceDB.lookup_latest_before_t64, GncPrice)
+
 GncPriceDB.add_methods_with_prefix('gnc_pricedb_')
 PriceDB_dict =  {
                 'lookup_latest' : GncPrice,
                 'lookup_nearest_in_time64' : GncPrice,
-                'lookup_latest_before_t64' : GncPrice,
+                'lookup_nearest_before_t64' : GncPrice,
                 'convert_balance_latest_price' : GncNumeric,
                 'convert_balance_nearest_price_t64' : GncNumeric,
                 }
@@ -417,7 +777,6 @@ methods_return_instance(GncPriceDB,PriceDB_dict)
 GncPriceDB.get_prices = method_function_returns_instance_list(
     GncPriceDB.get_prices, GncPrice )
 
-
 class GncCommodity(GnuCashCoreClass): pass
 
 class GncCommodityTable(GnuCashCoreClass):
@@ -533,6 +892,9 @@ Session.decorate_functions(one_arg_default_none, "load", "save")
 
 Session.decorate_functions( Session.raise_backend_errors_after_call,
                             "begin", "load", "save", "end")
+Session.decorate_method(default_arguments_decorator, "begin", None, mode=SessionOpenMode.SESSION_NORMAL_OPEN)
+Session.decorate_functions(deprecated_args_session_begin, "begin")
+
 Session.get_book = method_function_returns_instance(
     Session.get_book, Book )
 
@@ -565,7 +927,7 @@ from gnucash.gnucash_core_c import \
 # used for the how argument in arithmetic functions like GncNumeric.add
 from gnucash.gnucash_core_c import \
     GNC_HOW_DENOM_EXACT, GNC_HOW_DENOM_REDUCE, GNC_HOW_DENOM_LCD, \
-    GNC_HOW_DENOM_FIXED
+    GNC_HOW_DENOM_FIXED, GNC_HOW_DENOM_SIGFIG
 
 # import account types
 from gnucash.gnucash_core_c import \
@@ -606,7 +968,8 @@ gncnumeric_dict =   {
                         'add_fixed' : GncNumeric,
                         'sub_fixed' : GncNumeric,
                         'convert' : GncNumeric,
-                        'reduce' : GncNumeric
+                        'reduce' : GncNumeric,
+                        'invert' : GncNumeric
                     }
 methods_return_instance(GncNumeric, gncnumeric_dict)
 
@@ -800,7 +1163,29 @@ from gnucash.gnucash_core_c import \
     QOF_COMPARE_EQUAL, \
     QOF_COMPARE_GT, \
     QOF_COMPARE_GTE, \
-    QOF_COMPARE_NEQ
+    QOF_COMPARE_NEQ, \
+    QOF_COMPARE_CONTAINS, \
+    QOF_COMPARE_NCONTAINS
+
+from gnucash.gnucash_core_c import \
+    QOF_DATE_MATCH_NORMAL, \
+    QOF_DATE_MATCH_DAY
+
+from gnucash.gnucash_core_c import \
+    QOF_NUMERIC_MATCH_DEBIT, \
+    QOF_NUMERIC_MATCH_CREDIT, \
+    QOF_NUMERIC_MATCH_ANY
+
+from gnucash.gnucash_core_c import \
+    QOF_GUID_MATCH_ANY, \
+    QOF_GUID_MATCH_NONE, \
+    QOF_GUID_MATCH_NULL, \
+    QOF_GUID_MATCH_ALL, \
+    QOF_GUID_MATCH_LIST_ANY
+
+from gnucash.gnucash_core_c import \
+    QOF_CHAR_MATCH_ANY, \
+    QOF_CHAR_MATCH_NONE
 
 from gnucash.gnucash_core_c import \
     INVOICE_TYPE
@@ -859,3 +1244,9 @@ class QueryGuidPredicate(GnuCashCoreClass):
 
 QueryGuidPredicate.add_constructor_and_methods_with_prefix(
     'qof_query_', 'guid_predicate')
+
+class QueryNumericPredicate(GnuCashCoreClass):
+    pass
+
+QueryNumericPredicate.add_constructor_and_methods_with_prefix(
+    'qof_query_', 'numeric_predicate')
