@@ -298,7 +298,7 @@ gnc_window_adjust_for_screen(GtkWindow * window)
 }
 
 /********************************************************************\
- * Sets the alignament of a Label Widget, GTK3 version specific.    *
+ * Sets the alignment of a Label Widget, GTK3 version specific.    *
  *                                                                  *
  * Args: widget - the label widget to set alignment on              *
  *       xalign - x alignment                                       *
@@ -431,7 +431,7 @@ gnc_gdate_in_valid_range (GDate *test_date, gboolean warn)
 
     if (warn && !ret)
     {
-            // Transators: Use your locale date format here!
+            // Translators: Use your locale date format here!
         gchar *dialog_msg = _("The entered date is out of the range "
                   "01/01/1400 - 31/12/9999, resetting to this year");
         gchar *dialog_title = _("Date out of range");
@@ -749,18 +749,12 @@ gnc_dialog_run (GtkDialog *dialog, const gchar *pref_name)
         return response;
 
     /* Add in the checkboxes to find out if the answer should be remembered. */
-#if 0
     if (GTK_IS_MESSAGE_DIALOG(dialog))
     {
         GtkMessageType type;
         g_object_get(dialog, "message-type", &type, (gchar*)NULL);
-        ask = (type == GTK_MESSAGE_QUESTION);
+        ask = (type == GTK_MESSAGE_QUESTION || type == GTK_MESSAGE_WARNING);
     }
-    else
-    {
-        ask = FALSE;
-    }
-#endif
     perm = gtk_check_button_new_with_mnemonic
            (ask
             ? _("Remember and don't _ask me again.")
@@ -832,3 +826,22 @@ gnc_get_negative_color (void)
 
     return gdk_rgba_to_string (&color);
 }
+
+void
+gnc_owner_window_set_title (GtkWindow *window, const char *header,
+                            GtkWidget *owner_entry, GtkWidget *id_entry)
+{
+    const char *name = gtk_entry_get_text (GTK_ENTRY (owner_entry));
+    if (!name || *name == '\0')
+        name = _("<No name>");
+
+    const char *id = gtk_entry_get_text (GTK_ENTRY (id_entry));
+
+    char *title = (id && *id) ?
+        g_strdup_printf ("%s - %s (%s)", header, name, id) :
+        g_strdup_printf ("%s - %s", header, name);
+
+    gtk_window_set_title (window, title);
+
+    g_free (title);
+}
