@@ -63,8 +63,6 @@
 /* This static indicates the debugging module that this .o belongs to.  */
 G_GNUC_UNUSED static QofLogModule log_module = GNC_MOD_GUI;
 
-static void gnc_plugin_basic_commands_class_init (GncPluginBasicCommandsClass *klass);
-static void gnc_plugin_basic_commands_init (GncPluginBasicCommands *plugin);
 static void gnc_plugin_basic_commands_finalize (GObject *object);
 
 static void gnc_plugin_basic_commands_add_to_window (GncPlugin *plugin, GncMainWindow *window, GQuark type);
@@ -177,18 +175,12 @@ static const gchar *dirty_only_active_actions[] =
     NULL
 };
 
-/** The instance private data structure for an basic commands
- *  plugin. */
-typedef struct GncPluginBasicCommandsPrivate
+/** The instance data structure for an basic commands menu plugin. */
+struct _GncPluginBasicCommands
 {
-    gpointer dummy;
-} GncPluginBasicCommandsPrivate;
-
-#define GNC_PLUGIN_BASIC_COMMANDS_GET_PRIVATE(o)  \
-   ((GncPluginBasicCommandsPrivate*)gnc_plugin_basic_commands_get_instance_private ((GncPluginBasicCommands*)o))
-
-/** A pointer to the parent class of a plugin page. */
-static GObjectClass *parent_class = NULL;
+    /** The parent object for this widget */
+    GncPlugin gnc_plugin;
+};
 
 /** Create a new basic commands menu plugin. */
 GncPlugin *
@@ -276,7 +268,7 @@ gnc_plugin_basic_commands_main_window_page_changed (GncMainWindow *window,
     }
 }
 
-G_DEFINE_TYPE_WITH_PRIVATE(GncPluginBasicCommands, gnc_plugin_basic_commands, GNC_TYPE_PLUGIN)
+G_DEFINE_TYPE(GncPluginBasicCommands, gnc_plugin_basic_commands, GNC_TYPE_PLUGIN)
 
 /** Initialize the class for a new basic commands plugin.  This will
  *  set up any function pointers that override functions in the parent
@@ -291,8 +283,6 @@ gnc_plugin_basic_commands_class_init (GncPluginBasicCommandsClass *klass)
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GncPluginClass *plugin_class = GNC_PLUGIN_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (klass);
-
     object_class->finalize = gnc_plugin_basic_commands_finalize;
 
     /* plugin info */
@@ -334,7 +324,7 @@ gnc_plugin_basic_commands_finalize (GObject *object)
 {
     g_return_if_fail (GNC_IS_PLUGIN_BASIC_COMMANDS(object));
 
-    G_OBJECT_CLASS(parent_class)->finalize (object);
+    G_OBJECT_CLASS(gnc_plugin_basic_commands_parent_class)->finalize (object);
 }
 
 /************************************************************
@@ -388,7 +378,8 @@ gnc_main_window_cmd_file_save (GSimpleAction *simple,
 
     g_return_if_fail (data != NULL);
 
-    if (!gnc_main_window_all_finish_pending ())
+    if (!gnc_main_window_all_finish_pending () ||
+        gnc_file_save_in_progress())
         return;
 
     gnc_window_set_progressbar_window (GNC_WINDOW(data->window));
@@ -405,7 +396,8 @@ gnc_main_window_cmd_file_save_as (GSimpleAction *simple,
 
     g_return_if_fail (data != NULL);
 
-    if (!gnc_main_window_all_finish_pending ())
+    if (!gnc_main_window_all_finish_pending () ||
+        gnc_file_save_in_progress())
         return;
 
     gnc_window_set_progressbar_window (GNC_WINDOW(data->window));
@@ -483,6 +475,7 @@ gnc_main_window_cmd_actions_since_last_run (GSimpleAction *simple,
     GncSxInstanceModel *sx_instances;
     GncSxSummary summary;
     GList *auto_created_txns = NULL;
+    GList *creation_errors = NULL;
     const char *nothing_to_do_msg =
         _( "There are no Scheduled Transactions to be entered at this time." );
 
@@ -498,7 +491,8 @@ gnc_main_window_cmd_actions_since_last_run (GSimpleAction *simple,
 
     sx_instances = gnc_sx_get_current_instances();
     gnc_sx_instance_model_summarize(sx_instances, &summary);
-    gnc_sx_instance_model_effect_change(sx_instances, TRUE, &auto_created_txns, NULL);
+    gnc_sx_instance_model_effect_change(sx_instances, TRUE, &auto_created_txns,
+                                        &creation_errors);
 
     if (auto_created_txns)
         gnc_gui_refresh_all();
@@ -529,6 +523,9 @@ gnc_main_window_cmd_actions_since_last_run (GSimpleAction *simple,
     }
     g_list_free (auto_created_txns);
     g_object_unref (G_OBJECT(sx_instances));
+
+    if (creation_errors)
+        gnc_ui_sx_creation_error_dialog (&creation_errors);
 }
 
 static void
