@@ -75,6 +75,7 @@
 #include "gnc-icons.h"
 #include "print-session.h"
 
+#include <unordered_map>
 #include <memory>
 #include <gnc-report.h>
 
@@ -85,10 +86,9 @@ with qof_log_set_level().*/
 static QofLogModule log_module = GNC_MOD_GUI;
 
 // A static GHashTable to record the usage count for each printer
-// output name. FIXME: Currently this isn't cleaned up at program
-// shutdown because there isn't a place to easily insert a finalize()
-// function for this. Oh well.
-static GHashTable *static_report_printnames = nullptr;
+// output name.
+
+static std::unordered_map<std::string,unsigned> static_report_printnames;
 
 // Property-id values.
 enum
@@ -102,7 +102,7 @@ typedef struct GncPluginPageReportPrivate
     /// The report-id
     int reportId;
     gint component_manager_id;
-
+    GSimpleActionGroup* action_group;
     /// The report which this Page is satisfying
     SCM cur_report;
     /// The Option DB for this report.
@@ -201,6 +201,18 @@ static GActionEntry report_actions[] =
     { "ReportStopAction", gnc_plugin_page_report_stop_cb, nullptr, nullptr, nullptr },
 };
 static guint num_report_actions = G_N_ELEMENTS(report_actions);
+static const gchar *initially_insensitive_actions[] =
+{
+    nullptr
+};
+
+static const gchar *disable_during_load_actions[] =
+{
+    "FilePrintAction",
+    "FilePrintPDFAction",
+    "ReportOptionsAction",
+    nullptr
+};
 
 /** The default menu items that need to be add to the menu */
 static const gchar *gnc_plugin_load_ui_items [] =
@@ -323,7 +335,7 @@ gnc_plugin_page_report_focus_widget (GncPluginPage *report_plugin_page)
             if (!priv->loaded) // so we only do the load once
                 gnc_plugin_page_report_load_uri (report_plugin_page);
 
-            if (GTK_IS_WIDGET(widget))
+            if (widget && GTK_IS_WIDGET(widget))
             {
                 if (!gtk_widget_is_focus (GTK_WIDGET(widget)))
                     gtk_widget_grab_focus (GTK_WIDGET(widget));
@@ -366,11 +378,6 @@ gnc_plugin_page_report_class_init (GncPluginPageReportClass *klass)
                                              _("The numeric ID of the report."),
                                                        -1, G_MAXINT, -1,
                                                        paramspec));
-
-    // Also initialize the report name usage count table
-    if (!static_report_printnames)
-        static_report_printnames = g_hash_table_new_full(g_str_hash,
-                                   g_str_equal, g_free, nullptr);
 }
 
 static void
@@ -448,6 +455,8 @@ gnc_plugin_page_report_load_uri (GncPluginPage *page)
         g_object_remove_weak_pointer(G_OBJECT(page), (gpointer*)(&weak_page));
     }
 
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, TRUE);
     // this resets the window for the progressbar to nullptr
     gnc_window_set_progressbar_window( nullptr );
 }
@@ -799,6 +808,8 @@ gnc_plugin_page_report_option_change_cb(gpointer data)
     /* it's probably already dirty, but make sure */
     scm_call_2(dirty_report, priv->cur_report, SCM_BOOL_T);
 
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, FALSE);
     // prevent closing this page while loading...
     priv->reloading = TRUE;
 
@@ -816,6 +827,8 @@ gnc_plugin_page_report_option_change_cb(gpointer data)
     // this resets the window for the progressbar to nullptr
     gnc_window_set_progressbar_window( nullptr );
 
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, TRUE);
     priv->reloading = FALSE;
 }
 
@@ -1180,14 +1193,11 @@ gnc_plugin_page_report_destroy(GncPluginPageReportPrivate * priv)
         scm_gc_unprotect_object(priv->edited_reports);
 }
 
-static const gchar *initially_insensitive_actions[] =
-{
-    nullptr
-};
-
 static void
 gnc_plugin_page_report_init ( GncPluginPageReport *plugin_page )
 {
+    GncPluginPageReportPrivate *priv = GNC_PLUGIN_PAGE_REPORT_GET_PRIVATE(plugin_page);
+    priv->action_group = NULL;
 }
 
 static GObject*
@@ -1282,7 +1292,6 @@ static void
 gnc_plugin_page_report_constr_init (GncPluginPageReport *plugin_page, gint reportId)
 {
     GncPluginPageReportPrivate *priv;
-    GSimpleActionGroup *simple_action_group;
     GncPluginPage *parent;
     gboolean use_new;
     gchar *name;
@@ -1309,14 +1318,16 @@ gnc_plugin_page_report_constr_init (GncPluginPageReport *plugin_page, gint repor
     gnc_plugin_page_add_book (parent, gnc_get_current_book());
 
     /* Create menu and toolbar information */
-    simple_action_group = gnc_plugin_page_create_action_group (parent, "GncPluginPageReportActions");
-    g_action_map_add_action_entries (G_ACTION_MAP(simple_action_group),
+    priv->action_group = gnc_plugin_page_create_action_group (parent, "GncPluginPageReportActions");
+    g_action_map_add_action_entries (G_ACTION_MAP(priv->action_group),
                                      report_actions,
                                      num_report_actions,
                                      plugin_page);
 
-    gnc_plugin_set_actions_enabled (G_ACTION_MAP(simple_action_group), initially_insensitive_actions,
+    gnc_plugin_set_actions_enabled (G_ACTION_MAP(priv->action_group), initially_insensitive_actions,
                                     FALSE);
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, FALSE);
 }
 
 GncPluginPage*
@@ -1461,7 +1472,9 @@ gnc_plugin_page_report_reload_cb (GSimpleAction *simple,
     scm_call_2(dirty_report, priv->cur_report, SCM_BOOL_T);
 
     /* now queue the fact that we need to reload this report */
-
+    // Disable some actions reported to crash while loading
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, FALSE);
     // prevent closing this page while loading...
     priv->reloading = TRUE;
     // this sets the window for the progressbar
@@ -1476,6 +1489,8 @@ gnc_plugin_page_report_reload_cb (GSimpleAction *simple,
 
     // this resets the window for the progressbar to nullptr
     gnc_window_set_progressbar_window( nullptr );
+    gnc_plugin_set_actions_enabled(G_ACTION_MAP(priv->action_group),
+                                   disable_during_load_actions, TRUE);
     priv->reloading = FALSE;
 }
 
@@ -1947,32 +1962,16 @@ static gchar *report_create_jobname(GncPluginPageReportPrivate *priv)
     {
         /* And one final checking issue: We want to avoid allocating
          * the same name twice for a saved PDF.  Hence, we keep a
-         * GHashTable with the usage count of existing output
-         * names. (Because I'm lazy, I just use a static GHashTable
-         * for this.) */
-        gpointer value;
-        gboolean already_found;
-        g_assert(static_report_printnames);
+         * unordered_map with the usage count of existing output
+         * names. */
 
-        // Lookup the existing usage count
-        value = g_hash_table_lookup(static_report_printnames, job_name);
-        already_found = (value != nullptr);
-        if (!value)
-        {
-            value = GINT_TO_POINTER(0);
-        }
+        auto& value = static_report_printnames[job_name];
+        value++;
 
-        // Increment the stored usage count
-        value = GINT_TO_POINTER(1 + GPOINTER_TO_INT(value));
-        // and store it again
-        g_hash_table_insert(static_report_printnames, g_strdup(job_name), value);
-
-        // If the previous usage count was more than 0, append the current
-        // count (which is now 2 or higher) to the resulting name
-        if (already_found)
+        if (value > 1)
         {
             // The name was already in use, so modify the name again
-            gchar *tmp = g_strdup_printf("%s_%d", job_name, (int) GPOINTER_TO_INT(value));
+            gchar *tmp = g_strdup_printf("%s_%d", job_name, value);
             g_free(job_name);
             job_name = tmp;
         }
