@@ -45,7 +45,7 @@ gnc_default_currency(void)
 class GncMockQuoteSource final : public GncQuoteSource
 {
     const std::string m_version{"9.99"};
-    const StrVec m_sources{"currency", "yahoo_json"};
+    const StrVec m_sources{"currency", "alphavantage"};
     const StrVec m_quotes;
     const StrVec m_errors;
 public:
@@ -90,10 +90,15 @@ protected:
     m_book{qof_session_get_book(gnc_get_current_session())}
     {
         qof_init();
-        gnc_commodity_table_register();
-        gnc_pricedb_register();
+
+        /* By setting an empty commodity table on the book before registering
+         * the commodity_table type we avoid adding the default commodities */
         auto comm_table{gnc_commodity_table_new()};
         qof_book_set_data(m_book, GNC_COMMODITY_TABLE, comm_table);
+
+        gnc_commodity_table_register();
+        gnc_pricedb_register();
+
         auto eur = gnc_commodity_new(m_book, "Euro", "ISO4217", "EUR", NULL, 100);
         auto source{gnc_quote_source_lookup_by_internal("currency")};
         gnc_commodity_begin_edit(eur);
@@ -101,18 +106,16 @@ protected:
         gnc_commodity_set_quote_source(eur, source);
         gnc_commodity_commit_edit(eur);
         gnc_commodity_table_insert(comm_table, eur);
-        auto usd = gnc_commodity_new(m_book, "United States Dollar", "CURRENCY",
-                                  "USD", NULL, 100);
+        auto usd = gnc_commodity_new(m_book, "United States Dollar", "CURRENCY", "USD", NULL, 100);
         gnc_commodity_table_insert(comm_table, usd);
-        source = gnc_quote_source_lookup_by_internal("yahoo_json");
+        source = gnc_quote_source_lookup_by_internal("alphavantage");
         auto aapl = gnc_commodity_new(m_book, "Apple", "NASDAQ", "AAPL", NULL, 1);
         gnc_commodity_begin_edit(aapl);
         gnc_commodity_set_quote_flag(aapl, TRUE);
         gnc_commodity_set_quote_source(aapl, source);
         gnc_commodity_commit_edit(aapl);
         gnc_commodity_table_insert(comm_table, aapl);
-        auto hpe = gnc_commodity_new(m_book, "Hewlett Packard", "NYSE", "HPE",
-                                  NULL, 1);
+        auto hpe = gnc_commodity_new(m_book, "Hewlett Packard", "NYSE", "HPE", NULL, 1);
         gnc_commodity_begin_edit(hpe);
         gnc_commodity_set_quote_flag(hpe, TRUE);
         gnc_commodity_set_quote_source(hpe, source);
@@ -124,10 +127,12 @@ protected:
         gnc_commodity_set_quote_source(fkcm, source);
         gnc_commodity_commit_edit(fkcm);
         gnc_commodity_table_insert(comm_table, fkcm);
-        gnc_quote_source_set_fq_installed("TestSuite", g_list_prepend(nullptr, (void*)"yahoo_json"));
+        std::vector<std::string> sources = {"alphavantage"};
+        gnc_quote_source_set_fq_installed("TestSuite", sources);
     }
     ~GncQuotesTest() {
         gnc_clear_current_session();
+        qof_close();
     }
 
     QofSession* m_session;
@@ -143,8 +148,8 @@ TEST_F(GncQuotesTest, quote_sources)
     EXPECT_TRUE(qs_yahoo != nullptr);
     EXPECT_TRUE(qs_alpha != nullptr);
     EXPECT_TRUE(gnc_quote_source_get_supported(qs_cur));
-    EXPECT_TRUE(gnc_quote_source_get_supported(qs_yahoo));
-    EXPECT_FALSE(gnc_quote_source_get_supported(qs_alpha));
+    EXPECT_FALSE(gnc_quote_source_get_supported(qs_yahoo));
+    EXPECT_TRUE(gnc_quote_source_get_supported(qs_alpha));
 }
 
 TEST_F(GncQuotesTest, quotable_commodities)
@@ -176,17 +181,19 @@ TEST_F(GncQuotesTest, offline_wiggle)
 {
     StrVec quote_vec{
         "{"
-        "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004},"
-        "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Yahoo Finance (as JSON)\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"yahoo_json\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
-        "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"yahoo_json\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Yahoo Finance (as JSON)\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1},"
+         "\"currency\":{"
+        "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004}},"
+        "\"alphavantage\":{"
+        "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Alphavantage\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"alphavantage\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
+        "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"alphavantage\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Alphavantage\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1},"
         "\"FKCM\":{\"success\":0,\"symbol\":\"FKCM\",\"errormsg\":\"Error retrieving quote for FKCM - no listing for this name found. Please check symbol and the two letter extension (if any)\"}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     GncQuotesImpl quotes(m_book, std::make_unique<GncMockQuoteSource>(std::move(quote_vec), std::move(err_vec)));
     quotes.fetch(m_book);
     auto failures{quotes.failures()};
-    ASSERT_EQ(1u, failures.size());
+    EXPECT_EQ(1u, failures.size());
     EXPECT_EQ(GncQuoteError::QUOTE_FAILED, std::get<2>(failures[0]));
     auto pricedb{gnc_pricedb_get_db(m_book)};
     EXPECT_EQ(3u, gnc_pricedb_get_num_prices(pricedb));
@@ -196,24 +203,26 @@ TEST_F(GncQuotesTest, offline_report)
 {
     StrVec quote_vec{
         "{"
-        "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Yahoo Finance (as JSON)\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"yahoo_json\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
-        "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"yahoo_json\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Yahoo Finance (as JSON)\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1},"
+        "\"alphavantage\":{"
+        "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Alphavantage\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"alphavantage\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
+        "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"alphavantage\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Alphavantage\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1},"
         "\"FKCM\":{\"success\":0,\"symbol\":\"FKCM\",\"errormsg\":\"Error retrieving quote for FKCM - no listing for this name found. Please check symbol and the two letter extension (if any)\"}"
-        "}"
+        "}}"
     };
     StrVec commodities{"AAPL", "HPE", "FKCM"};
     StrVec err_vec;
     GncQuotesImpl quotes(m_book, std::make_unique<GncMockQuoteSource>(std::move(quote_vec), std::move(err_vec)));
-    quotes.report("yahoo_json", commodities, false);
-    quotes.report("yahoo_json", commodities, true);
+    quotes.report("alphavantage", commodities, false);
+    quotes.report("alphavantage", commodities, true);
 }
 
 TEST_F(GncQuotesTest, offline_currency_report)
 {
     StrVec quote_vec{
         "{"
+         "\"currency\":{"
         "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004}"
-        "}"
+        "}}"
     };
     StrVec commodities{"USD", "EUR"};
     StrVec err_vec;
@@ -226,9 +235,10 @@ TEST_F(GncQuotesTest, comvec_fetch)
 {
      StrVec quote_vec{
         "{"
-        "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Yahoo Finance (as JSON)\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"yahoo_json\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
-        "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"yahoo_json\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Yahoo Finance (as JSON)\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1}"
-        "}"
+        "\"alphavantage\":{"
+        "\"AAPL\":{\"eps\":6.05,\"success\":1,\"year_range\":\"      129.04 - 182.94\",\"currency\":\"USD\",\"exchange\":\"Sourced from Alphavantage\",\"volume\":73539475,\"close\":157.22,\"high\":158.39,\"open\":156.64,\"div_yield\":0.5660857,\"last\":157.96,\"isodate\":\"2022-09-01\",\"method\":\"alphavantage\",\"name\":\"AAPL (Apple Inc.)\",\"pe\":26.10909,\"low\":154.67,\"type\":\"EQUITY\",\"symbol\":\"AAPL\",\"date\":\"09/01/2022\"},"
+        "\"HPE\":{\"symbol\":\"HPE\",\"date\":\"09/01/2022\",\"low\":13.13,\"type\":\"EQUITY\",\"method\":\"alphavantage\",\"name\":\"HPE (Hewlett Packard Enterprise Comp)\",\"isodate\":\"2022-09-01\",\"pe\":4.7921147,\"last\":13.37,\"high\":13.535,\"close\":13.6,\"open\":13.5,\"div_yield\":3.5294116,\"volume\":16370483,\"exchange\":\"Sourced from Alphavantage\",\"currency\":\"USD\",\"year_range\":\"        12.4 - 17.76\",\"eps\":2.79,\"success\":1}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -247,8 +257,9 @@ TEST_F(GncQuotesTest, fetch_one_commodity)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"currency\":\"USD\",\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -260,7 +271,7 @@ TEST_F(GncQuotesTest, fetch_one_commodity)
     EXPECT_TRUE(failures.empty());
     auto pricedb{gnc_pricedb_get_db(m_book)};
     auto price{gnc_pricedb_lookup_latest(pricedb, hpe, usd)};
-    auto datetime{static_cast<time64>(GncDateTime("20220901160000"))};
+    auto datetime{static_cast<time64>(GncDateTime("20220901105900"))};
 
     EXPECT_EQ(usd, gnc_price_get_currency(price));
     EXPECT_EQ(datetime, gnc_price_get_time64(price));
@@ -269,14 +280,16 @@ TEST_F(GncQuotesTest, fetch_one_commodity)
                                   gnc_price_get_value(price)));
     EXPECT_STREQ("Finance::Quote", gnc_price_get_source_string(price));
     EXPECT_STREQ("last", gnc_price_get_typestr(price));
+    gnc_price_unref(price);
 }
 
 TEST_F(GncQuotesTest, fetch_one_currency)
 {
      StrVec quote_vec{
          "{"
+         "\"currency\":{"
          "\"EUR\":{\"symbol\":\"EUR\",\"currency\":\"USD\",\"success\":\"1\",\"inverted\":0,\"last\":1.0004}"
-         "}"
+         "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -299,14 +312,16 @@ TEST_F(GncQuotesTest, fetch_one_currency)
                                   gnc_price_get_value(price)));
     EXPECT_STREQ("Finance::Quote", gnc_price_get_source_string(price));
     EXPECT_STREQ("last", gnc_price_get_typestr(price));
+    gnc_price_unref(price);
 }
 
 TEST_F(GncQuotesTest, no_currency)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -324,8 +339,9 @@ TEST_F(GncQuotesTest, bad_currency)
 {
      StrVec quote_vec{
         "{"
-        "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"currency\":\"BTC\",\"success\":1}"
-        "}"
+       "\"alphavantage\":{"
+         "\"HPE\":{\"date\":\"09/01/2022\",\"last\":13.37,\"currency\":\"BTC\",\"success\":1}"
+        "}}"
      };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -343,8 +359,9 @@ TEST_F(GncQuotesTest, no_date)
 {
      StrVec quote_vec{
         "{"
+        "\"alphavantage\":{"
         "\"HPE\":{\"last\":13.37,\"currency\":\"USD\",\"success\":1}"
-        "}"
+        "}}"
     };
     StrVec err_vec;
     auto commtable{gnc_commodity_table_get_table(m_book)};
@@ -365,6 +382,7 @@ TEST_F(GncQuotesTest, no_date)
                                   gnc_price_get_value(price)));
     EXPECT_STREQ("Finance::Quote", gnc_price_get_source_string(price));
     EXPECT_STREQ("last", gnc_price_get_typestr(price));
+    gnc_price_unref(price);
 }
 
 TEST_F(GncQuotesTest, test_version)
