@@ -22,12 +22,9 @@
 \********************************************************************/
 
 #include <guid.hpp>
-extern "C"
-{
 #include <config.h>
 #include <platform.h>
 #include <gnc-locale-utils.h>
-}
 
 #include <string>
 #include <regex>
@@ -46,14 +43,13 @@ const std::string lock_table = "gnclock";
 class GncDbiSqlStatement : public GncSqlStatement
 {
 public:
-    GncDbiSqlStatement(const GncSqlConnection* conn, const std::string& sql) :
-        m_conn{conn}, m_sql {sql} {}
+    GncDbiSqlStatement(const std::string& sql) :
+        m_sql {sql} {}
     ~GncDbiSqlStatement() {}
     const char* to_sql() const override;
     void add_where_cond(QofIdTypeConst, const PairVec&) override;
 
 private:
-    const GncSqlConnection* m_conn = nullptr;
     std::string m_sql;
 };
 
@@ -177,7 +173,8 @@ GncDbiSqlConnection::unlock_database ()
 {
     if (m_conn == nullptr) return;
     if (m_readonly) return;
-    g_return_if_fail (dbi_conn_error (m_conn, nullptr) == 0);
+    auto dbi_error{dbi_conn_error (m_conn, nullptr)};
+    g_return_if_fail (dbi_error == DBI_ERROR_NONE || dbi_error == DBI_ERROR_BADIDX);
 
     auto tables = m_provider->get_table_list (m_conn, lock_table);
     if (tables.empty())
@@ -324,7 +321,7 @@ GncSqlStatementPtr
 GncDbiSqlConnection::create_statement_from_sql (const std::string& sql)
     const noexcept
 {
-    return std::unique_ptr<GncSqlStatement>{new GncDbiSqlStatement (this, sql)};
+    return std::unique_ptr<GncSqlStatement>{new GncDbiSqlStatement (sql)};
 }
 
 bool
@@ -485,7 +482,7 @@ create_index_ddl (const GncSqlConnection* conn, const std::string& index_name,
 {
     std::string ddl;
     ddl += "CREATE INDEX " + index_name + " ON " + table_name + "(";
-    for (auto const table_row : col_table)
+    for (const auto& table_row : col_table)
     {
         if (table_row != *col_table.begin())
         {
@@ -543,7 +540,6 @@ GncDbiSqlConnection::quote_string (const std::string& unquoted_str)
     const noexcept
 {
     char* quoted_str;
-    size_t size;
 
     dbi_conn_quote_string_copy (m_conn, unquoted_str.c_str(),
                                 &quoted_str);
@@ -556,7 +552,7 @@ GncDbiSqlConnection::quote_string (const std::string& unquoted_str)
 
 
 /** Check if the dbi connection is valid. If not attempt to re-establish it
- * Returns TRUE is there is a valid connection in the end or FALSE otherwise
+ * Returns TRUE if there is a valid connection in the end or FALSE otherwise
  */
 bool
 GncDbiSqlConnection::verify () noexcept
