@@ -5,15 +5,15 @@
 
 #include <qofbook.h>
 #include <qofbook-p.h>
+#include <Split.h>
 
 #include "gmock-gobject.h"
-#include "gmock-Split.h"
 
 
-GType qof_mock_book_get_type(void);
+GType qof_mockbook_get_type(void);
 
-#define QOF_TYPE_MOCK_BOOK   (qof_mock_book_get_type ())
-#define QOF_IS_MOCK_BOOK(o)  (G_TYPE_CHECK_INSTANCE_TYPE ((o), QOF_TYPE_MOCK_BOOK))
+#define QOF_TYPE_MOCKBOOK   (qof_mockbook_get_type ())
+#define QOF_IS_MOCKBOOK(o)  (G_TYPE_CHECK_INSTANCE_TYPE ((o), QOF_TYPE_MOCKBOOK))
 
 
 // mock up for QofBook
@@ -37,7 +37,7 @@ public:
     }
     void* operator new(size_t size)
     {
-        return mock_g_object_new (QOF_TYPE_MOCK_BOOK, NULL, size);
+        return mock_g_object_new (QOF_TYPE_MOCKBOOK, NULL, size);
     }
 
     // define separate free() function since destructor is protected
@@ -50,8 +50,8 @@ public:
         mock_g_object_unref(book, size);
     }
 
-    MOCK_METHOD0(mallocSplit, Split *());
-    MOCK_METHOD0(useSplitActionForNumField, gboolean());
+    MOCK_METHOD0(malloc_split, Split *());
+    MOCK_CONST_METHOD0(use_split_action_for_num_field, gboolean());
 
 protected:
     // Protect destructor to avoid MockQofBook objects to be created on stack. MockQofBook
@@ -59,4 +59,25 @@ protected:
     ~QofMockBook() {}
 };
 
+
+// type conversion functions
+static inline QofMockBook*
+qof_mockbook (QofBook *book)
+{
+    if (QOF_IS_MOCKBOOK(book))
+        return static_cast<QofMockBook*>(book);
+    ADD_FAILURE() << "Expected 'book' to be of type 'QofMockBook'";
+    return nullptr;
+}
+
+static inline const QofMockBook*
+qof_mockbook (const QofBook *book)
+{
+    if (QOF_IS_MOCKBOOK(book))
+        return static_cast<const QofMockBook*>(book);
+    ADD_FAILURE() << "Expected 'book' to be of type 'QofMockBook'";
+    return nullptr;
+}
+
+
 #endif
