@@ -21,8 +21,12 @@
 \********************************************************************/
 
 #include <gtest/gtest.h>
+#include <cstdint>
 #include "../gnc-numeric.hpp"
 #include "../gnc-rational.hpp"
+#ifdef __APPLE__
+#include <sys/sysctl.h>
+#endif
 
 TEST(gncnumeric_constructors, test_default_constructor)
 {
@@ -140,6 +144,10 @@ TEST(gncnumeric_constructors, test_string_constructor)
     GncNumeric neg_simple_decimal("-123.456");
     EXPECT_EQ(-123456, neg_simple_decimal.num());
     EXPECT_EQ(1000, neg_simple_decimal.denom());
+    ASSERT_NO_THROW(GncNumeric thousep_decimal("123,456,789.123"));
+    GncNumeric thousep_decimal("123,456,789.123");
+    EXPECT_EQ(123456789123, thousep_decimal.num());
+    EXPECT_EQ(1000, thousep_decimal.denom());
     ASSERT_NO_THROW(GncNumeric continental_decimal("123,456"));
     GncNumeric continental_decimal("123,456");
     EXPECT_EQ(123456, continental_decimal.num());
@@ -148,6 +156,10 @@ TEST(gncnumeric_constructors, test_string_constructor)
     GncNumeric neg_continental_decimal("-123,456");
     EXPECT_EQ(-123456, neg_continental_decimal.num());
     EXPECT_EQ(1000, neg_continental_decimal.denom());
+    ASSERT_NO_THROW(GncNumeric swiss_thousep_decimal("123""\xe2\x80\xaf""456""\xe2\x80\xaf""789,123"));
+    GncNumeric swiss_thousep_decimal("123""\xe2\x80\xaf""456""\xe2\x80\xaf""789,123");
+    EXPECT_EQ(123456789123, swiss_thousep_decimal.num());
+    EXPECT_EQ(1000, swiss_thousep_decimal.denom());
     GncNumeric from_scientific("1.234e4");
     EXPECT_EQ(12340, from_scientific.num());
     EXPECT_EQ(1, from_scientific.denom());
@@ -180,10 +192,35 @@ TEST(gncnumeric_constructors, test_string_constructor)
     GncNumeric neg_embedded("The number is -123456/456");
     EXPECT_EQ(-123456, neg_embedded.num());
     EXPECT_EQ(456, neg_embedded.denom());
+    ASSERT_NO_THROW(GncNumeric integer_fraction("The number is 1234 567/890"));
+    GncNumeric integer_fraction("The number is 1234 567/890");
+    EXPECT_EQ(1098827, integer_fraction.num());
+    EXPECT_EQ(890, integer_fraction.denom());
+    ASSERT_NO_THROW(GncNumeric neg_integer_fraction("The number is -1234 567/890"));
+    GncNumeric neg_integer_fraction("The number is -1234 567/890");
+    EXPECT_EQ(-1098827, neg_integer_fraction.num());
+    EXPECT_EQ(890, neg_integer_fraction.denom());
+    GncNumeric integer_large_fraction("The number is 1234 4567/890");
+    EXPECT_EQ(1102827, integer_large_fraction.num());
+    EXPECT_EQ(890, integer_large_fraction.denom());
+    GncNumeric neg_integer_large_fraction("The number is -1234 4567/890");
+    EXPECT_EQ(-1102827, neg_integer_large_fraction.num());
+    EXPECT_EQ(890, neg_integer_large_fraction.denom());
+    ASSERT_NO_THROW(GncNumeric zero_integer_fraction("The number is 0 567/890"));
+    GncNumeric zero_integer_fraction("The number is 0 567/890");
+    EXPECT_EQ(567, zero_integer_fraction.num());
+    EXPECT_EQ(890, zero_integer_fraction.denom());
+    ASSERT_NO_THROW(GncNumeric neg_zero_integer_fraction("The number is -0 567/890"));
+    GncNumeric neg_zero_integer_fraction("The number is -0 567/890");
+    EXPECT_EQ(-567, neg_zero_integer_fraction.num());
+    EXPECT_EQ(890, neg_zero_integer_fraction.denom());
     EXPECT_THROW(GncNumeric throw_zero_denom("123/0"), std::invalid_argument);
     EXPECT_THROW(GncNumeric overflow("12345678987654321.123456"),
                  std::overflow_error);
     EXPECT_NO_THROW(GncNumeric overflow("12345678987654321.123456", true));
+    EXPECT_NO_THROW(GncNumeric limit64a("-9223372036854775808/9223372036854775807"));
+    EXPECT_THROW(GncNumeric limit64b("-9223372036854775809/9223372036854775807"), std::out_of_range);
+    EXPECT_THROW(GncNumeric limit64c("-9223372036854775808/9223372036854775808"), std::out_of_range);
     GncNumeric overflow("12345678987654321.123456", true);
     EXPECT_EQ(6028163568190586486, overflow.num());
     EXPECT_EQ(488, overflow.denom());
@@ -221,6 +258,23 @@ TEST(gncnumeric_output, string_output)
     EXPECT_EQ("-123/456", neg_rational_string.to_string());
 }
 
+#ifdef __APPLE__
+static float
+get_macos_version()
+{
+    int major, minor, micro;
+    float rv{};
+    char vstr[64];
+    size_t len = sizeof(vstr);
+    auto err = sysctlbyname("kern.osrelease", vstr, &len, nullptr, 0);
+    if (err)
+        return rv;
+    sscanf(vstr, "%d.%d.%d", &major, &minor, &micro);
+    rv = major + minor / 100.0 + micro / 10000.0;
+    return rv;
+}
+#endif
+
 TEST(gncnumeric_stream, output_stream)
 {
     std::ostringstream output;
@@ -252,6 +306,12 @@ TEST(gncnumeric_stream, output_stream)
         output.imbue(std::locale("fr_FR"));
         output.str("");
         output << simple_int;
+// Apple fixed this in macOS 15.4 to include the separator.
+#ifdef __APPLE__
+        if (get_macos_version() >= 24.04)
+            EXPECT_EQ("123\xe2\x80\xaf""456", output.str());
+        else
+#endif
         EXPECT_EQ("123456", output.str());
     }
     output.str("");
@@ -405,6 +465,28 @@ TEST(gncnumeric_functions, test_cmp)
     EXPECT_EQ(1, a.cmp(INT64_C(12500)));
 }
 
+TEST(gncnumeric_functions, test_operators)
+{
+    GncNumeric a(123456789, 9876), b(567894321, 6543);
+    auto c = a;
+    EXPECT_TRUE (b > a);
+    EXPECT_TRUE (a < b);
+    EXPECT_TRUE (b >= a);
+    EXPECT_TRUE (a <= b);
+    EXPECT_TRUE (a == c);
+    EXPECT_TRUE (b != c);
+
+    auto zero = INT64_C(0);
+    EXPECT_TRUE (b > zero);
+    EXPECT_TRUE (zero < a);
+    EXPECT_TRUE (b >= zero);
+    EXPECT_TRUE (zero <= b);
+    EXPECT_TRUE (a != zero);
+    EXPECT_TRUE (zero != a);
+    EXPECT_FALSE (a == zero);
+    EXPECT_FALSE (zero == a);
+}
+
 TEST(gncnumeric_functions, test_invert)
 {
     GncNumeric a(123456789, 9876), b, c;
